createHaplotypeTable: Create haplotype table

View source: R/internal_functions.R

createHaplotypeTableR Documentation

Create haplotype table

Description

createHaplotypeTable Haplotype of a specific gene

Usage

createHaplotypeTable(
  df,
  HapByPriors = c(0.5, 0.5),
  toHapByCol = TRUE,
  toHapPriors = c(0.5, 0.5)
)

Arguments

df

table of counts

HapByPriors

vector of frequencies of each of the anchor gene alleles

toHapByCol

logical, haplotype each chromosome separetly to imrove the aligner assignmnet

toHapPriors

vector of frequencies of the haplotyped gene alleles

Value

data frame with chromosomal associasions of alleles of a specific gene


rabhit documentation built on July 24, 2026, 5:07 p.m.