View source: R/internal_functions.R
| createHaplotypeTable | R Documentation |
createHaplotypeTable Haplotype of a specific gene
createHaplotypeTable(
df,
HapByPriors = c(0.5, 0.5),
toHapByCol = TRUE,
toHapPriors = c(0.5, 0.5)
)
df |
table of counts |
HapByPriors |
vector of frequencies of each of the anchor gene alleles |
toHapByCol |
logical, haplotype each chromosome separetly to imrove the aligner assignmnet |
toHapPriors |
vector of frequencies of the haplotyped gene alleles |
data frame with chromosomal associasions of alleles of a specific gene
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.