Learn R Programming

rabhit (version 0.4.0)

createHaplotypeTable: Create haplotype table

Description

createHaplotypeTable Haplotype of a specific gene

Usage

createHaplotypeTable(
  df,
  HapByPriors = c(0.5, 0.5),
  toHapByCol = TRUE,
  toHapPriors = c(0.5, 0.5)
)

Value

data frame with chromosomal associasions of alleles of a specific gene

Arguments

df

table of counts

HapByPriors

vector of frequencies of each of the anchor gene alleles

toHapByCol

logical, haplotype each chromosome separetly to imrove the aligner assignmnet

toHapPriors

vector of frequencies of the haplotyped gene alleles