createHaplotypeTable Haplotype of a specific gene
createHaplotypeTable(
df,
HapByPriors = c(0.5, 0.5),
toHapByCol = TRUE,
toHapPriors = c(0.5, 0.5)
)data frame with chromosomal associasions of alleles of a specific gene
table of counts
vector of frequencies of each of the anchor gene alleles
logical, haplotype each chromosome separetly to imrove the aligner assignmnet
vector of frequencies of the haplotyped gene alleles